@@ -24,17 +24,17 @@ describe Puppet::Provider::Sahara do
 
     it 'should read conf file with all sections' do
       creds_hash = {
-        'auth_uri'          => 'https://192.168.56.210:35357/v2.0/',
-        'admin_tenant_name' => 'admin_tenant',
-        'admin_user'        => 'admin',
-        'admin_password'    => 'password',
+        'www_authenticate_uri' => 'https://192.168.56.210:35357/v2.0/',
+        'admin_tenant_name'    => 'admin_tenant',
+        'admin_user'           => 'admin',
+        'admin_password'       => 'password',
       }
       mock = {
         'keystone_authtoken' => {
-          'auth_uri'          => 'https://192.168.56.210:35357/v2.0/',
-          'admin_tenant_name' => 'admin_tenant',
-          'admin_user'        => 'admin',
-          'admin_password'    => 'password',
+          'www_authenticate_uri' => 'https://192.168.56.210:35357/v2.0/',
+          'admin_tenant_name'    => 'admin_tenant',
+          'admin_user'           => 'admin',
+          'admin_password'       => 'password',
         }
       }
       Puppet::Util::IniConfig::File.expects(:new).returns(mock)
